@@ -86,7 +86,7 @@ typedef enum {
     GNOME_RR_ERROR_NO_DPMS_EXTENSION,	/* DPMS extension is not present */
 } GnomeRRError;
 
-#define GNOME_RR_CONNECTOR_TYPE_PANEL "Panel"  /* This is a laptop's built-in LCD */
+#define GNOME_RR_CONNECTOR_TYPE_PANEL "Panel"  /* This is a built-in LCD */
 
 #define GNOME_TYPE_RR_SCREEN                  (gnome_rr_screen_get_type())
 #define GNOME_RR_SCREEN(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_TYPE_RR_SCREEN, GnomeRRScreen))
@@ -107,15 +107,15 @@ GType gnome_rr_mode_get_type (void);
 /* GnomeRRScreen */
 GnomeRRScreen * gnome_rr_screen_new                (GdkScreen             *screen,
 						    GError               **error);
+void            gnome_rr_screen_new_async          (GdkScreen             *screen,
+                                                    GAsyncReadyCallback    callback,
+                                                    gpointer               user_data);
+GnomeRRScreen * gnome_rr_screen_new_finish         (GAsyncResult          *result,
+                                                    GError               **error);
 GnomeRROutput **gnome_rr_screen_list_outputs       (GnomeRRScreen         *screen);
 GnomeRRCrtc **  gnome_rr_screen_list_crtcs         (GnomeRRScreen         *screen);
 GnomeRRMode **  gnome_rr_screen_list_modes         (GnomeRRScreen         *screen);
 GnomeRRMode **  gnome_rr_screen_list_clone_modes   (GnomeRRScreen	  *screen);
-void            gnome_rr_screen_set_size           (GnomeRRScreen         *screen,
-						    int                    width,
-						    int                    height,
-						    int                    mm_width,
-						    int                    mm_height);
 GnomeRRCrtc *   gnome_rr_screen_get_crtc_by_id     (GnomeRRScreen         *screen,
 						    guint32                id);
 gboolean        gnome_rr_screen_refresh            (GnomeRRScreen         *screen,
@@ -129,14 +129,6 @@ void            gnome_rr_screen_get_ranges         (GnomeRRScreen         *scree
 						    int                   *max_width,
 						    int                   *min_height,
 						    int                   *max_height);
-void            gnome_rr_screen_get_timestamps     (GnomeRRScreen         *screen,
-						    guint32               *change_timestamp_ret,
-						    guint32               *config_timestamp_ret);
-
-void            gnome_rr_screen_set_primary_output (GnomeRRScreen         *screen,
-                                                    GnomeRROutput         *output);
-
-GnomeRRMode   **gnome_rr_screen_create_clone_modes (GnomeRRScreen *screen);
 
 gboolean        gnome_rr_screen_get_dpms_mode      (GnomeRRScreen        *screen,
                                                     GnomeRRDpmsMode       *mode,
@@ -149,21 +141,18 @@ gboolean        gnome_rr_screen_set_dpms_mode      (GnomeRRScreen         *scree
 guint32         gnome_rr_output_get_id             (GnomeRROutput         *output);
 const char *    gnome_rr_output_get_name           (GnomeRROutput         *output);
 const char *    gnome_rr_output_get_display_name   (GnomeRROutput         *output);
-gboolean        gnome_rr_output_is_connected       (GnomeRROutput         *output);
-int             gnome_rr_output_get_size_inches    (GnomeRROutput         *output);
-int             gnome_rr_output_get_width_mm       (GnomeRROutput         *outout);
-int             gnome_rr_output_get_height_mm      (GnomeRROutput         *output);
 const guint8 *  gnome_rr_output_get_edid_data      (GnomeRROutput         *output,
-                                                    gsize                 *size);
-gboolean        gnome_rr_output_get_ids_from_edid  (GnomeRROutput         *output,
+						    gsize                 *size);
+void            gnome_rr_output_get_ids_from_edid  (GnomeRROutput         *output,
                                                     char                 **vendor,
-                                                    int                   *product,
-                                                    int                   *serial);
+                                                    char                 **product,
+                                                    char                 **serial);
+void            gnome_rr_output_get_physical_size  (GnomeRROutput         *output,
+                                                    int                   *width_mm,
+                                                    int                   *height_mm);
 
-gint            gnome_rr_output_get_backlight_min  (GnomeRROutput         *output);
-gint            gnome_rr_output_get_backlight_max  (GnomeRROutput         *output);
-gint            gnome_rr_output_get_backlight      (GnomeRROutput         *output,
-                                                    GError                **error);
+gint            gnome_rr_output_get_backlight      (GnomeRROutput         *output);
+gint            gnome_rr_output_get_min_backlight_step(GnomeRROutput      *output);
 gboolean        gnome_rr_output_set_backlight      (GnomeRROutput         *output,
                                                     gint                   value,
                                                     GError                **error);
@@ -171,8 +160,7 @@ gboolean        gnome_rr_output_set_backlight      (GnomeRROutput         *outpu
 GnomeRRCrtc **  gnome_rr_output_get_possible_crtcs (GnomeRROutput         *output);
 GnomeRRMode *   gnome_rr_output_get_current_mode   (GnomeRROutput         *output);
 GnomeRRCrtc *   gnome_rr_output_get_crtc           (GnomeRROutput         *output);
-const char *    gnome_rr_output_get_connector_type (GnomeRROutput         *output);
-gboolean        gnome_rr_output_is_laptop          (GnomeRROutput         *output);
+gboolean        gnome_rr_output_is_builtin_display (GnomeRROutput         *output);
 void            gnome_rr_output_get_position       (GnomeRROutput         *output,
 						    int                   *x,
 						    int                   *y);
@@ -193,15 +181,6 @@ int             gnome_rr_mode_get_freq             (GnomeRRMode           *mode)
 /* GnomeRRCrtc */
 guint32         gnome_rr_crtc_get_id               (GnomeRRCrtc           *crtc);
 
-gboolean        gnome_rr_crtc_set_config_with_time (GnomeRRCrtc           *crtc,
-						    guint32                timestamp,
-						    int                    x,
-						    int                    y,
-						    GnomeRRMode           *mode,
-						    GnomeRRRotation        rotation,
-						    GnomeRROutput        **outputs,
-						    int                    n_outputs,
-						    GError               **error);
 gboolean        gnome_rr_crtc_can_drive_output     (GnomeRRCrtc           *crtc,
 						    GnomeRROutput         *output);
 GnomeRRMode *   gnome_rr_crtc_get_current_mode     (GnomeRRCrtc           *crtc);
@@ -218,9 +197,10 @@ gboolean        gnome_rr_crtc_get_gamma            (GnomeRRCrtc           *crtc,
 						    unsigned short       **red,
 						    unsigned short       **green,
 						    unsigned short       **blue);
-void            gnome_rr_crtc_set_gamma            (GnomeRRCrtc           *crtc,
+gboolean        gnome_rr_crtc_set_gamma            (GnomeRRCrtc           *crtc,
 						    int                    size,
 						    unsigned short        *red,
 						    unsigned short        *green,
 						    unsigned short        *blue);
+
 #endif /* GNOME_RR_H */
