@@ -25,9 +25,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <X11/XKBlib.h>
-#include <X11/extensions/XKBrules.h>
-
 #include <gdk/gdkx.h>
 
 #include <glib/gi18n-lib.h>
@@ -40,12 +37,6 @@
 #ifndef XKB_RULES_FILE
 #define XKB_RULES_FILE "evdev"
 #endif
-#ifndef XKB_LAYOUT
-#define XKB_LAYOUT "us"
-#endif
-#ifndef XKB_MODEL
-#define XKB_MODEL "pc105+inet"
-#endif
 
 typedef struct _Layout Layout;
 struct _Layout
@@ -56,6 +47,8 @@ struct _Layout
   gchar *description;
   gboolean is_variant;
   const Layout *main_layout;
+  GSList *iso639Ids;
+  GSList *iso3166Ids;
 };
 
 typedef struct _XkbOption XkbOption;
@@ -104,6 +97,8 @@ free_layout (gpointer data)
   g_free (layout->xkb_name);
   g_free (layout->short_desc);
   g_free (layout->description);
+  g_slist_free_full (layout->iso639Ids, g_free);
+  g_slist_free_full (layout->iso3166Ids, g_free);
   g_slice_free (Layout, layout);
 }
 
@@ -132,88 +127,13 @@ free_option_group (gpointer data)
   g_slice_free (XkbOptionGroup, group);
 }
 
-/**
- * gnome_xkb_info_get_var_defs: (skip)
- * @rules: (out) (transfer full): location to store the rules file
- * path. Use g_free() when it's no longer needed
- * @var_defs: (out) (transfer full): location to store a
- * #XkbRF_VarDefsRec pointer. Use gnome_xkb_info_free_var_defs() to
- * free it
- *
- * Gets both the XKB rules file path and the current XKB parameters in
- * use by the X server.
- *
- * Since: 3.6
- */
-void
-gnome_xkb_info_get_var_defs (gchar            **rules,
-                             XkbRF_VarDefsRec **var_defs)
-{
-  Display *display = GDK_DISPLAY_XDISPLAY (gdk_display_get_default ());
-  char *tmp;
-
-  g_return_if_fail (rules != NULL);
-  g_return_if_fail (var_defs != NULL);
-
-  *rules = NULL;
-  *var_defs = g_new0 (XkbRF_VarDefsRec, 1);
-
-  gdk_error_trap_push ();
-
-  /* Get it from the X property or fallback on defaults */
-  if (!XkbRF_GetNamesProp (display, rules, *var_defs) || !*rules)
-    {
-      *rules = strdup (XKB_RULES_FILE);
-      (*var_defs)->model = strdup (XKB_MODEL);
-      (*var_defs)->layout = strdup (XKB_LAYOUT);
-      (*var_defs)->variant = NULL;
-      (*var_defs)->options = NULL;
-    }
-
-  gdk_error_trap_pop_ignored ();
-
-  tmp = *rules;
-
-  if (*rules[0] == '/')
-    *rules = g_strdup (*rules);
-  else
-    *rules = g_build_filename (XKB_BASE, "rules", *rules, NULL);
-
-  free (tmp);
-}
-
-/**
- * gnome_xkb_info_free_var_defs: (skip)
- * @var_defs: #XkbRF_VarDefsRec instance to free
- *
- * Frees an #XkbRF_VarDefsRec instance allocated by
- * gnome_xkb_info_get_var_defs().
- *
- * Since: 3.6
- */
-void
-gnome_xkb_info_free_var_defs (XkbRF_VarDefsRec *var_defs)
-{
-  g_return_if_fail (var_defs != NULL);
-
-  free (var_defs->model);
-  free (var_defs->layout);
-  free (var_defs->variant);
-  free (var_defs->options);
-
-  g_free (var_defs);
-}
-
 static gchar *
 get_xml_rules_file_path (const gchar *suffix)
 {
-  XkbRF_VarDefsRec *xkb_var_defs;
   gchar *rules_file;
   gchar *xml_rules_file;
 
-  gnome_xkb_info_get_var_defs (&rules_file, &xkb_var_defs);
-  gnome_xkb_info_free_var_defs (xkb_var_defs);
-
+  rules_file = g_build_filename (XKB_BASE, "rules", XKB_RULES_FILE, NULL);
   xml_rules_file = g_strdup_printf ("%s%s", rules_file, suffix);
   g_free (rules_file);
 
@@ -367,7 +287,7 @@ add_layout_to_table (GHashTable  *table,
 {
   GHashTable *set;
 
-  if (!layout->xkb_name)
+  if (!layout->id)
     return;
 
   set = g_hash_table_lookup (table, key);
@@ -378,10 +298,64 @@ add_layout_to_table (GHashTable  *table,
     }
   else
     {
-      if (g_hash_table_contains (set, layout->xkb_name))
+      if (g_hash_table_contains (set, layout->id))
         return;
     }
-  g_hash_table_replace (set, layout->xkb_name, layout);
+  g_hash_table_replace (set, layout->id, layout);
+}
+
+static void
+add_layout_to_locale_tables (Layout     *layout,
+                             GHashTable *layouts_by_language,
+                             GHashTable *layouts_by_country)
+{
+  GSList *l, *lang_codes, *country_codes;
+  gchar *language, *country;
+
+  lang_codes = layout->iso639Ids;
+  country_codes = layout->iso3166Ids;
+
+  if (layout->is_variant)
+    {
+      if (!lang_codes)
+        lang_codes = layout->main_layout->iso639Ids;
+      if (!country_codes)
+        country_codes = layout->main_layout->iso3166Ids;
+    }
+
+  for (l = lang_codes; l; l = l->next)
+    {
+      language = gnome_get_language_from_code ((gchar *) l->data, NULL);
+      if (language)
+        {
+          add_layout_to_table (layouts_by_language, language, layout);
+          g_free (language);
+        }
+    }
+
+  for (l = country_codes; l; l = l->next)
+    {
+      country = gnome_get_country_from_code ((gchar *) l->data, NULL);
+      if (country)
+        {
+          add_layout_to_table (layouts_by_country, country, layout);
+          g_free (country);
+        }
+    }
+}
+
+static void
+add_iso639 (Layout *layout,
+            gchar  *id)
+{
+  layout->iso639Ids = g_slist_prepend (layout->iso639Ids, id);
+}
+
+static void
+add_iso3166 (Layout *layout,
+             gchar  *id)
+{
+  layout->iso3166Ids = g_slist_prepend (layout->iso3166Ids, id);
 }
 
 static void
@@ -412,6 +386,9 @@ parse_end_element (GMarkupParseContext  *context,
       g_hash_table_replace (priv->layouts_table,
                             priv->current_parser_layout->id,
                             priv->current_parser_layout);
+      add_layout_to_locale_tables (priv->current_parser_layout,
+                                   priv->layouts_by_language,
+                                   priv->layouts_by_country);
       priv->current_parser_layout = NULL;
     }
   else if (strcmp (element_name, "variant") == 0)
@@ -431,12 +408,13 @@ parse_end_element (GMarkupParseContext  *context,
       g_hash_table_replace (priv->layouts_table,
                             priv->current_parser_variant->id,
                             priv->current_parser_variant);
+      add_layout_to_locale_tables (priv->current_parser_variant,
+                                   priv->layouts_by_language,
+                                   priv->layouts_by_country);
       priv->current_parser_variant = NULL;
     }
   else if (strcmp (element_name, "iso639Id") == 0)
     {
-      gchar *language;
-
       if (!priv->current_parser_iso639Id)
         {
           g_set_error (error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
@@ -444,23 +422,15 @@ parse_end_element (GMarkupParseContext  *context,
           return;
         }
 
-      language = gnome_get_language_from_code (priv->current_parser_iso639Id, NULL);
-      if (language)
-        {
-          if (priv->current_parser_variant)
-            add_layout_to_table (priv->layouts_by_language, language, priv->current_parser_variant);
-          else if (priv->current_parser_layout)
-            add_layout_to_table (priv->layouts_by_language, language, priv->current_parser_layout);
+      if (priv->current_parser_variant)
+        add_iso639 (priv->current_parser_variant, priv->current_parser_iso639Id);
+      else if (priv->current_parser_layout)
+        add_iso639 (priv->current_parser_layout, priv->current_parser_iso639Id);
 
-          g_free (language);
-        }
-
-      g_clear_pointer (&priv->current_parser_iso639Id, g_free);
+      priv->current_parser_iso639Id = NULL;
     }
   else if (strcmp (element_name, "iso3166Id") == 0)
     {
-      gchar *country;
-
       if (!priv->current_parser_iso3166Id)
         {
           g_set_error (error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
@@ -468,18 +438,12 @@ parse_end_element (GMarkupParseContext  *context,
           return;
         }
 
-      country = gnome_get_country_from_code (priv->current_parser_iso3166Id, NULL);
-      if (country)
-        {
-          if (priv->current_parser_variant)
-            add_layout_to_table (priv->layouts_by_country, country, priv->current_parser_variant);
-          else if (priv->current_parser_layout)
-            add_layout_to_table (priv->layouts_by_country, country, priv->current_parser_layout);
+      if (priv->current_parser_variant)
+        add_iso3166 (priv->current_parser_variant, priv->current_parser_iso3166Id);
+      else if (priv->current_parser_layout)
+        add_iso3166 (priv->current_parser_layout, priv->current_parser_iso3166Id);
 
-          g_free (country);
-        }
-
-      g_clear_pointer (&priv->current_parser_iso3166Id, g_free);
+      priv->current_parser_iso3166Id = NULL;
     }
   else if (strcmp (element_name, "group") == 0)
     {
